@@ -19,10 +19,24 @@ import torch
 from torch import nn
 import numpy as np
 
-from fastNLP.modules.utils import _get_file_name_base_on_postfix
+
 from fastNLP.io.file_utils import _get_embedding_url, cached_path, PRETRAINED_BERT_MODEL_DIR
 from fastNLP.core import logger
 
+def _get_file_name_base_on_postfix(dir_path, postfix):
+    """
+    在dir_path中寻找后缀为postfix的文件.
+    :param dir_path: str, 文件夹
+    :param postfix: 形如".bin", ".json"等
+    :return: str，文件的路径
+    """
+    files = list(filter(lambda filename: filename.endswith(postfix), os.listdir(os.path.join(dir_path))))
+    if len(files) == 0:
+        raise FileNotFoundError(f"There is no file endswith *{postfix} file in {dir_path}")
+    elif len(files) > 1:
+        raise FileExistsError(f"There are multiple *{postfix} files in {dir_path}")
+    return os.path.join(dir_path, files[0])
+
 CONFIG_FILE = 'bert_config.json'
 VOCAB_NAME = 'vocab.txt'
 
